# Copyright 2019 The FastEstimator Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
from fastestimator.op.tensorop.loss.cross_entropy import CrossEntropy
from fastestimator.op.tensorop.loss.hinge import Hinge
from fastestimator.op.tensorop.loss.loss import LossOp
from fastestimator.op.tensorop.loss.mean_squared_error import MeanSquaredError
from fastestimator.op.tensorop.loss.mix_loss import MixLoss
